@@ -12,12 +12,12 @@ my $count = 0;
 sub process_msg_ch202 {
   my $m = shift;
   ++$count;
-  if (! $count % 100000) {
-    printf "len(srcips)=%d len(dstips)=%d\n",
-           scalar keys %srcips, scalar keys %dstips;
+  if (! $count % 10000) {
+    printf "%d len(srcips)=%d len(dstips)=%d\n",
+           $count, scalar keys %srcips, scalar keys %dstips;
   }
-  if ($m->get_proto == 17 && $m->get_srcport == 53) {
-    ++$srcips{$m->get_srcip};
+  if ($m->get_proto == 17 && $m->get_response_port == 53) {
+    ++$srcips{$m->get_response_ip};
     ++$dstips{$m->get_dstip};
   }
 }
@@ -25,6 +25,6 @@ sub process_msg_ch202 {
 my $io = Net::Nmsg::IO->new;
 
 $io->add_input_chalias('ch202');
-$io->set_filter_msgtype(base => 'ncap');
+$io->set_filter_msgtype(base => 'dnsqr');
 $io->add_output_cb(\&process_msg_ch202);
 $io->loop;
